@@ -1,4 +1,4 @@
-# volume.py
+
 
 """
 This module is an integeral part of the program
@@ -24,6 +24,7 @@ Bob van der Poel <bob@mellowood.ca>
 
 from MMA.common import *
 import MMA.debug
+import re
 
 """ Volumes are specified in musical terms, but converted to
     midi velocities. This table has a list of percentage changes
@@ -85,42 +86,56 @@ def adjvolume(ln):
               ' '.join([ "%s=%s" % (a, int(vols[a] * 100)) for a in sorted(vols)]))
 
 
+calcVolumeRePat = re.compile(
+    # This is a regular expression to parse the input for the calcVolume
+    # function. The details are embedded in the comments below.
+    # Thanks to Johan Vromans!
+
+    # Note, there are 2 parts to this. It's either numeric
+    # or mnemonic. We use a | to join the 2 halves.
+    # opt. +/- (assigned to 'pre'), numeric value ('val'), and optional % to 'post'
+    # Note the '$' terminator which forces NUMERIC[%] to be end.
+    r'(?P<pre>[-+])?(?P<val>[\d.]+)(?P<post>%)?$'
+    + '|' +
+    # mnemonic is assigned to 'mn'.
+    r'(?P<mn>[OFPM]+)$',re.IGNORECASE )
+
 def calcVolume(new, old):
     """ Calculate a new volume "new" possibly adjusting from "old". """
 
-    if new[0] == '-' or new[0] == '+':
-        a = stof(new, "Volume expecting value for %% adjustment, not %s" % new)
-        v = old + (old * a / 100.)
-        if v < 0:
-            v = 0
-            warning("Volume adjustment results in 0 volume.")
+    m = calcVolumeRePat.match(new)
+    if m is None:
+        error("Unknown volume '%s'" % new)
 
-    elif new[0] in "0123456789":
-        v = stof(new, "Volume expecting value, not '%s'" % new) / 100.
+    # Do we have a mnemonic?
 
-    else:
-        new = new.upper()
+    mn = m.group('mn')
+    if mn:
+        mn = mn.upper()
+        if not mn in vols:
+            error("Unknown volume mnemonic '%s'" % mn)
+        return vols[mn]
 
-        adj = None
+    # So it must be a value.
+    val  = m.group('val')
+    pre  = m.group('pre')
+    post = m.group('post')
 
-        if '+' in new:
-            new, adj = new.split('+')
-        elif '-' in new:
-            new, adj = new.split('-')
-            adj = '-' + adj
+    if pre and not post:
+        warning("Please use '%s%s%%' if you want to %screase the volume"
+                % (pre, val, "in" if pre == '+' else "de"))
 
-        if not new in vols:
-            error("Unknown volume '%s'" % new)
+    v = stof(val, "Volume expecting value, not '%s'" % val) / 100.
 
-        v = vols[new]
-
-        if adj:
-            a = stoi(adj, "Volume expecting adjustment value, not %s" % adj)
-            v += (v * (a / 100.))
+    if pre == '+':
+        v = old * ( 1 + v )
+    elif pre == '-':
+        v = old * ( 1 - v )
+    elif post == '%':
+        v = old * ( v )
 
     return v
 
-
 def setVolume(ln):
     """ Set master volume. """
 
@@ -133,7 +148,7 @@ def setVolume(ln):
 
     futureVol = []
     if MMA.debug.debug:
-        dPrint("Volume: %s%%" % volume)
+        dPrint("Volume: %s%%" % (100 * volume))
 
 
 # The next 3 are called from the parser.
